@@ -1,5 +1,5 @@
 /* GDHCPD, a GTK+ frontend for ISC DHCPD
- * Copyright C 2004, 2005 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright C 2004, 2005, 2006 Magnus Loef <magnus-swe@telia.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +23,13 @@
 #include <stdio.h>
 #include "widgets.h"
 #include "commands.h"
+#include "activate_button_clicked.h"
 
 extern int activated;
 extern char DHCPD_CONF_BUF[1024];
+extern char LEASE_FILE_BUF[1024];
+
 
-#include "activate_button_clicked.h"
 
 void activate_button_clicked(struct gdhcpd_widgets *widgets)
 {
@@ -36,6 +38,14 @@ void activate_button_clicked(struct gdhcpd_widgets *widgets)
     if( activated )
       return;
 
+    /* If the dhcpd.leases file doesnt exist it refuses to start */
+    if( ! file_exists(LEASE_FILE_BUF) )
+    {
+	start = g_strdup_printf("touch %s", LEASE_FILE_BUF);
+	run_command(start);
+	g_free(start);
+    }
+
     start = g_strdup_printf("%s -cf %s", DHCPD_BINARY, DHCPD_CONF_BUF);
     if( ! run_command(start) )
     {
