@@ -1,5 +1,5 @@
 /* GDHCPD, a GTK+ frontend for ISC DHCPD
- * Copyright C 2004, 2005 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright C 2004, 2005, 2006 Magnus Loef <magnus-swe@telia.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,18 +26,17 @@
 #include "delete_host_from_btn.h"
 #include "delete_host.h"
 #include "populate_host_treeview.h"
+#include "select_first_host.h"
 #include "populate_host_settings.h"
+#include "reread_conf.h"
 
 
 void delete_host_from_btn(struct gdhcpd_widgets *widgets)
 {
     delete_host(widgets);
-    /* Reread hosts */
     populate_host_treeview(widgets);
-
-//    select_first_host(widgets); FIXME
-
+    select_first_host(widgets);
     populate_host_settings(widgets);
 
-    /* reread_conf is done last in delete_host(); */
+    reread_conf();
 }
