@@ -1,5 +1,5 @@
 /* GDHCPD, a GTK+ frontend for ISC DHCPD
- * Copyright C 2004, 2005 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright C 2004, 2005, 2006 Magnus Loef <magnus-swe@telia.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,15 +27,15 @@
 #include "populate_scope_treeview.h"
 #include "select_first_scope.h"
 #include "list_scopes.h"
+#include "reread_conf.h"
 
 
 void delete_scope_from_btn(struct gdhcpd_widgets *widgets)
 {
     delete_scope(widgets);
-    /* Reread scopes */
     populate_scope_treeview(widgets);
     select_first_scope(widgets);
     list_scopes(widgets);
 
-    /* ReRead is done in delete_scope(); */
+    reread_conf();
 }
